# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dv_pyclient/grpc/dataSources.proto

from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from dv_pyclient.grpc import scalapb_pb2 as dv__pyclient_dot_grpc_dot_scalapb__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='dv_pyclient/grpc/dataSources.proto',
  package='com.datavorelabs.common.protos',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=b'\n\"dv_pyclient/grpc/dataSources.proto\x12\x1e\x63om.datavorelabs.common.protos\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1e\x64v_pyclient/grpc/scalapb.proto\"X\n\x0eOptionalString\x12+\n\x05value\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue:\x19\xe2?\x16\"\x14scala.Option[String]\"X\n\x0eOptionalNumber\x12+\n\x05value\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue:\x19\xe2?\x16\"\x14scala.Option[Double]\"S\n\x0cOptionalTime\x12*\n\x05value\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value:\x17\xe2?\x14\"\x12scala.Option[Long]\"\xba\x02\n\nDataRecord\x12\x64\n\x07strings\x18\x01 \x03(\x0b\x32..com.datavorelabs.common.protos.OptionalStringB#\xe2? \x1a\x1e\x63ollection.mutable.ArrayBuffer\x12\x64\n\x07numbers\x18\x02 \x03(\x0b\x32..com.datavorelabs.common.protos.OptionalNumberB#\xe2? \x1a\x1e\x63ollection.mutable.ArrayBuffer\x12`\n\x05times\x18\x03 \x03(\x0b\x32,.com.datavorelabs.common.protos.OptionalTimeB#\xe2? \x1a\x1e\x63ollection.mutable.ArrayBuffer\"O\n\x10\x44\x61taRecordsReply\x12;\n\x07records\x18\x01 \x03(\x0b\x32*.com.datavorelabs.common.protos.DataRecord\"\x18\n\x16ListDataSourcesRequest\",\n\x10\x44\x61taSourceResult\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"]\n\x14ListDataSourcesReply\x12\x45\n\x0b\x64\x61taSources\x18\x01 \x03(\x0b\x32\x30.com.datavorelabs.common.protos.DataSourceResult\"A\n\x18\x44\x61taSourceUniquesRequest\x12\x14\n\x0c\x64\x61taSourceId\x18\x01 \x01(\t\x12\x0f\n\x07\x63olumns\x18\x02 \x03(\t\"-\n\x15\x44\x61taSourceMetaRequest\x12\x14\n\x0c\x64\x61taSourceId\x18\x01 \x01(\t\"\xad\x01\n\x12StringColumnConfig\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x14\n\x0c\x64isplayLabel\x18\x02 \x01(\t\x12\x43\n\x08modifier\x18\x03 \x01(\x0e\x32\x31.com.datavorelabs.common.protos.PredicateModifier\x12.\n\x08ontology\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"8\n\x12NumberColumnConfig\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x14\n\x0c\x64isplayLabel\x18\x02 \x01(\t\"J\n\x10TimeColumnConfig\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x14\n\x0c\x64isplayLabel\x18\x02 \x01(\t\x12\x12\n\ndateFormat\x18\x03 \x01(\t\"\xe0\x01\n\x18StaticStringColumnConfig\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x14\n\x0c\x64isplayLabel\x18\x02 \x01(\t\x12+\n\x05value\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x43\n\x08modifier\x18\x04 \x01(\x0e\x32\x31.com.datavorelabs.common.protos.PredicateModifier\x12.\n\x08ontology\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"k\n\x18StaticNumberColumnConfig\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x14\n\x0c\x64isplayLabel\x18\x02 \x01(\t\x12+\n\x05value\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\"h\n\x16StaticTimeColumnConfig\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x14\n\x0c\x64isplayLabel\x18\x02 \x01(\t\x12*\n\x05value\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\"\xa6\x04\n\x0c\x43olumnConfig\x12P\n\x12stringColumnConfig\x18\x01 \x01(\x0b\x32\x32.com.datavorelabs.common.protos.StringColumnConfigH\x00\x12P\n\x12numberColumnConfig\x18\x02 \x01(\x0b\x32\x32.com.datavorelabs.common.protos.NumberColumnConfigH\x00\x12L\n\x10timeColumnConfig\x18\x03 \x01(\x0b\x32\x30.com.datavorelabs.common.protos.TimeColumnConfigH\x00\x12\\\n\x18staticStringColumnConfig\x18\x04 \x01(\x0b\x32\x38.com.datavorelabs.common.protos.StaticStringColumnConfigH\x00\x12\\\n\x18staticNumberColumnConfig\x18\x05 \x01(\x0b\x32\x38.com.datavorelabs.common.protos.StaticNumberColumnConfigH\x00\x12X\n\x16staticTimeColumnConfig\x18\x06 \x01(\x0b\x32\x36.com.datavorelabs.common.protos.StaticTimeColumnConfigH\x00\x42\x0e\n\x0c\x63olumnConfig\":\n\x0fTimeTupleConfig\x12\x12\n\ntimeColumn\x18\x01 \x01(\t\x12\x13\n\x0bvalueColumn\x18\x02 \x01(\t\"\xe2\x01\n\x0f\x44\x61taLoadMapping\x12\x12\n\nkeyColumns\x18\x01 \x03(\t\x12\x16\n\x0evalueModifiers\x18\x02 \x03(\t\x12\x13\n\x0btimeColumns\x18\x03 \x03(\t\x12/\n\tfrequency\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x18\n\x10valueLabelColumn\x18\x05 \x03(\t\x12\x43\n\ntimeTuples\x18\x06 \x03(\x0b\x32/.com.datavorelabs.common.protos.TimeTupleConfig\"2\n\x0c\x43olumnSample\x12\x12\n\ncolumnName\x18\x01 \x01(\t\x12\x0e\n\x06values\x18\x02 \x03(\t\"K\n\tRowSample\x12>\n\x06values\x18\x02 \x03(\x0b\x32..com.datavorelabs.common.protos.OptionalString\"\xd6\x02\n\x13\x44\x61taSourceMetaReply\x12\x14\n\x0c\x64\x61taSourceId\x18\x01 \x01(\t\x12\x16\n\x0e\x64\x61taSourceName\x18\x02 \x01(\t\x12\x43\n\rcolumnConfigs\x18\x03 \x03(\x0b\x32,.com.datavorelabs.common.protos.ColumnConfig\x12H\n\x0f\x64\x61taLoadMapping\x18\x04 \x01(\x0b\x32/.com.datavorelabs.common.protos.DataLoadMapping\x12=\n\nsampleData\x18\x05 \x03(\x0b\x32).com.datavorelabs.common.protos.RowSample\x12\x43\n\rcolumnSamples\x18\x06 \x03(\x0b\x32,.com.datavorelabs.common.protos.ColumnSample\"\xe4\x01\n\x0eLineDefinition\x12\x17\n\x0fkeyPredicateIds\x18\x01 \x03(\t\x12?\n\x07keyPath\x18\x02 \x03(\x0b\x32..com.datavorelabs.common.protos.OptionalString\x12\x17\n\x0ftimePredicateId\x18\x03 \x01(\t\x12\x18\n\x10valuePredicateId\x18\x04 \x01(\t\x12/\n\tfrequency\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x14\n\x0c\x64\x61taSourceId\x18\x06 \x01(\t\"\xa3\x02\n\x0bQueryColumn\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x38\n\x04type\x18\x02 \x01(\x0e\x32*.com.datavorelabs.common.protos.ColumnType\x12\x44\n\x0cstringFilter\x18\x03 \x03(\x0b\x32..com.datavorelabs.common.protos.OptionalString\x12\x44\n\x0cnumberFilter\x18\x04 \x03(\x0b\x32..com.datavorelabs.common.protos.OptionalNumber\x12@\n\ntimeFilter\x18\x05 \x03(\x0b\x32,.com.datavorelabs.common.protos.OptionalTime\"I\n\tLineQuery\x12<\n\x07\x63olumns\x18\x01 \x03(\x0b\x32+.com.datavorelabs.common.protos.QueryColumn\"X\n\x16\x44\x61taSourceQueryRequest\x12>\n\x0blineQueries\x18\x01 \x03(\x0b\x32).com.datavorelabs.common.protos.LineQuery*B\n\x11PredicateModifier\x12\x08\n\x04None\x10\x00\x12\x10\n\x0cTimeModifier\x10\x01\x12\x11\n\rValueModifier\x10\x02*.\n\nColumnType\x12\n\n\x06String\x10\x00\x12\n\n\x06Number\x10\x01\x12\x08\n\x04Time\x10\x02\x32\xa4\x04\n\x10RemoteDataSource\x12\x81\x01\n\x0fListDataSources\x12\x36.com.datavorelabs.common.protos.ListDataSourcesRequest\x1a\x34.com.datavorelabs.common.protos.ListDataSourcesReply\"\x00\x12\x83\x01\n\x11\x64\x61taSourceUniques\x12\x38.com.datavorelabs.common.protos.DataSourceUniquesRequest\x1a\x30.com.datavorelabs.common.protos.DataRecordsReply\"\x00\x30\x01\x12\x84\x01\n\x14sampleDataSourceMeta\x12\x35.com.datavorelabs.common.protos.DataSourceMetaRequest\x1a\x33.com.datavorelabs.common.protos.DataSourceMetaReply\"\x00\x12\x7f\n\x0f\x64\x61taSourceQuery\x12\x36.com.datavorelabs.common.protos.DataSourceQueryRequest\x1a\x30.com.datavorelabs.common.protos.DataRecordsReply\"\x00\x30\x01\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,dv__pyclient_dot_grpc_dot_scalapb__pb2.DESCRIPTOR,])

_PREDICATEMODIFIER = _descriptor.EnumDescriptor(
  name='PredicateModifier',
  full_name='com.datavorelabs.common.protos.PredicateModifier',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='None', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TimeModifier', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ValueModifier', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3836,
  serialized_end=3902,
)
_sym_db.RegisterEnumDescriptor(_PREDICATEMODIFIER)

PredicateModifier = enum_type_wrapper.EnumTypeWrapper(_PREDICATEMODIFIER)
_COLUMNTYPE = _descriptor.EnumDescriptor(
  name='ColumnType',
  full_name='com.datavorelabs.common.protos.ColumnType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='String', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Number', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Time', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3904,
  serialized_end=3950,
)
_sym_db.RegisterEnumDescriptor(_COLUMNTYPE)

ColumnType = enum_type_wrapper.EnumTypeWrapper(_COLUMNTYPE)
globals()['None'] = 0
TimeModifier = 1
ValueModifier = 2
String = 0
Number = 1
Time = 2



_OPTIONALSTRING = _descriptor.Descriptor(
  name='OptionalString',
  full_name='com.datavorelabs.common.protos.OptionalString',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='com.datavorelabs.common.protos.OptionalString.value', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\026\"\024scala.Option[String]',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=134,
  serialized_end=222,
)


_OPTIONALNUMBER = _descriptor.Descriptor(
  name='OptionalNumber',
  full_name='com.datavorelabs.common.protos.OptionalNumber',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='com.datavorelabs.common.protos.OptionalNumber.value', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\026\"\024scala.Option[Double]',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=224,
  serialized_end=312,
)


_OPTIONALTIME = _descriptor.Descriptor(
  name='OptionalTime',
  full_name='com.datavorelabs.common.protos.OptionalTime',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='com.datavorelabs.common.protos.OptionalTime.value', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\024\"\022scala.Option[Long]',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=314,
  serialized_end=397,
)


_DATARECORD = _descriptor.Descriptor(
  name='DataRecord',
  full_name='com.datavorelabs.common.protos.DataRecord',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='strings', full_name='com.datavorelabs.common.protos.DataRecord.strings', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342? \032\036collection.mutable.ArrayBuffer', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='numbers', full_name='com.datavorelabs.common.protos.DataRecord.numbers', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342? \032\036collection.mutable.ArrayBuffer', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='times', full_name='com.datavorelabs.common.protos.DataRecord.times', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342? \032\036collection.mutable.ArrayBuffer', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=400,
  serialized_end=714,
)


_DATARECORDSREPLY = _descriptor.Descriptor(
  name='DataRecordsReply',
  full_name='com.datavorelabs.common.protos.DataRecordsReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='records', full_name='com.datavorelabs.common.protos.DataRecordsReply.records', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=716,
  serialized_end=795,
)


_LISTDATASOURCESREQUEST = _descriptor.Descriptor(
  name='ListDataSourcesRequest',
  full_name='com.datavorelabs.common.protos.ListDataSourcesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=797,
  serialized_end=821,
)


_DATASOURCERESULT = _descriptor.Descriptor(
  name='DataSourceResult',
  full_name='com.datavorelabs.common.protos.DataSourceResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='com.datavorelabs.common.protos.DataSourceResult.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='com.datavorelabs.common.protos.DataSourceResult.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=823,
  serialized_end=867,
)


_LISTDATASOURCESREPLY = _descriptor.Descriptor(
  name='ListDataSourcesReply',
  full_name='com.datavorelabs.common.protos.ListDataSourcesReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dataSources', full_name='com.datavorelabs.common.protos.ListDataSourcesReply.dataSources', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=869,
  serialized_end=962,
)


_DATASOURCEUNIQUESREQUEST = _descriptor.Descriptor(
  name='DataSourceUniquesRequest',
  full_name='com.datavorelabs.common.protos.DataSourceUniquesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dataSourceId', full_name='com.datavorelabs.common.protos.DataSourceUniquesRequest.dataSourceId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='columns', full_name='com.datavorelabs.common.protos.DataSourceUniquesRequest.columns', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=964,
  serialized_end=1029,
)


_DATASOURCEMETAREQUEST = _descriptor.Descriptor(
  name='DataSourceMetaRequest',
  full_name='com.datavorelabs.common.protos.DataSourceMetaRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dataSourceId', full_name='com.datavorelabs.common.protos.DataSourceMetaRequest.dataSourceId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1031,
  serialized_end=1076,
)


_STRINGCOLUMNCONFIG = _descriptor.Descriptor(
  name='StringColumnConfig',
  full_name='com.datavorelabs.common.protos.StringColumnConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='com.datavorelabs.common.protos.StringColumnConfig.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='displayLabel', full_name='com.datavorelabs.common.protos.StringColumnConfig.displayLabel', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='modifier', full_name='com.datavorelabs.common.protos.StringColumnConfig.modifier', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ontology', full_name='com.datavorelabs.common.protos.StringColumnConfig.ontology', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1079,
  serialized_end=1252,
)


_NUMBERCOLUMNCONFIG = _descriptor.Descriptor(
  name='NumberColumnConfig',
  full_name='com.datavorelabs.common.protos.NumberColumnConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='com.datavorelabs.common.protos.NumberColumnConfig.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='displayLabel', full_name='com.datavorelabs.common.protos.NumberColumnConfig.displayLabel', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1254,
  serialized_end=1310,
)


_TIMECOLUMNCONFIG = _descriptor.Descriptor(
  name='TimeColumnConfig',
  full_name='com.datavorelabs.common.protos.TimeColumnConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='com.datavorelabs.common.protos.TimeColumnConfig.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='displayLabel', full_name='com.datavorelabs.common.protos.TimeColumnConfig.displayLabel', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dateFormat', full_name='com.datavorelabs.common.protos.TimeColumnConfig.dateFormat', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1312,
  serialized_end=1386,
)


_STATICSTRINGCOLUMNCONFIG = _descriptor.Descriptor(
  name='StaticStringColumnConfig',
  full_name='com.datavorelabs.common.protos.StaticStringColumnConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='com.datavorelabs.common.protos.StaticStringColumnConfig.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='displayLabel', full_name='com.datavorelabs.common.protos.StaticStringColumnConfig.displayLabel', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='com.datavorelabs.common.protos.StaticStringColumnConfig.value', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='modifier', full_name='com.datavorelabs.common.protos.StaticStringColumnConfig.modifier', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ontology', full_name='com.datavorelabs.common.protos.StaticStringColumnConfig.ontology', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1389,
  serialized_end=1613,
)


_STATICNUMBERCOLUMNCONFIG = _descriptor.Descriptor(
  name='StaticNumberColumnConfig',
  full_name='com.datavorelabs.common.protos.StaticNumberColumnConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='com.datavorelabs.common.protos.StaticNumberColumnConfig.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='displayLabel', full_name='com.datavorelabs.common.protos.StaticNumberColumnConfig.displayLabel', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='com.datavorelabs.common.protos.StaticNumberColumnConfig.value', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1615,
  serialized_end=1722,
)


_STATICTIMECOLUMNCONFIG = _descriptor.Descriptor(
  name='StaticTimeColumnConfig',
  full_name='com.datavorelabs.common.protos.StaticTimeColumnConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='com.datavorelabs.common.protos.StaticTimeColumnConfig.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='displayLabel', full_name='com.datavorelabs.common.protos.StaticTimeColumnConfig.displayLabel', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='com.datavorelabs.common.protos.StaticTimeColumnConfig.value', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1724,
  serialized_end=1828,
)


_COLUMNCONFIG = _descriptor.Descriptor(
  name='ColumnConfig',
  full_name='com.datavorelabs.common.protos.ColumnConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='stringColumnConfig', full_name='com.datavorelabs.common.protos.ColumnConfig.stringColumnConfig', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='numberColumnConfig', full_name='com.datavorelabs.common.protos.ColumnConfig.numberColumnConfig', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timeColumnConfig', full_name='com.datavorelabs.common.protos.ColumnConfig.timeColumnConfig', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='staticStringColumnConfig', full_name='com.datavorelabs.common.protos.ColumnConfig.staticStringColumnConfig', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='staticNumberColumnConfig', full_name='com.datavorelabs.common.protos.ColumnConfig.staticNumberColumnConfig', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='staticTimeColumnConfig', full_name='com.datavorelabs.common.protos.ColumnConfig.staticTimeColumnConfig', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='columnConfig', full_name='com.datavorelabs.common.protos.ColumnConfig.columnConfig',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=1831,
  serialized_end=2381,
)


_TIMETUPLECONFIG = _descriptor.Descriptor(
  name='TimeTupleConfig',
  full_name='com.datavorelabs.common.protos.TimeTupleConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='timeColumn', full_name='com.datavorelabs.common.protos.TimeTupleConfig.timeColumn', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='valueColumn', full_name='com.datavorelabs.common.protos.TimeTupleConfig.valueColumn', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2383,
  serialized_end=2441,
)


_DATALOADMAPPING = _descriptor.Descriptor(
  name='DataLoadMapping',
  full_name='com.datavorelabs.common.protos.DataLoadMapping',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='keyColumns', full_name='com.datavorelabs.common.protos.DataLoadMapping.keyColumns', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='valueModifiers', full_name='com.datavorelabs.common.protos.DataLoadMapping.valueModifiers', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timeColumns', full_name='com.datavorelabs.common.protos.DataLoadMapping.timeColumns', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='frequency', full_name='com.datavorelabs.common.protos.DataLoadMapping.frequency', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='valueLabelColumn', full_name='com.datavorelabs.common.protos.DataLoadMapping.valueLabelColumn', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timeTuples', full_name='com.datavorelabs.common.protos.DataLoadMapping.timeTuples', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2444,
  serialized_end=2670,
)


_COLUMNSAMPLE = _descriptor.Descriptor(
  name='ColumnSample',
  full_name='com.datavorelabs.common.protos.ColumnSample',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='columnName', full_name='com.datavorelabs.common.protos.ColumnSample.columnName', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='values', full_name='com.datavorelabs.common.protos.ColumnSample.values', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2672,
  serialized_end=2722,
)


_ROWSAMPLE = _descriptor.Descriptor(
  name='RowSample',
  full_name='com.datavorelabs.common.protos.RowSample',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='values', full_name='com.datavorelabs.common.protos.RowSample.values', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2724,
  serialized_end=2799,
)


_DATASOURCEMETAREPLY = _descriptor.Descriptor(
  name='DataSourceMetaReply',
  full_name='com.datavorelabs.common.protos.DataSourceMetaReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dataSourceId', full_name='com.datavorelabs.common.protos.DataSourceMetaReply.dataSourceId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dataSourceName', full_name='com.datavorelabs.common.protos.DataSourceMetaReply.dataSourceName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='columnConfigs', full_name='com.datavorelabs.common.protos.DataSourceMetaReply.columnConfigs', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dataLoadMapping', full_name='com.datavorelabs.common.protos.DataSourceMetaReply.dataLoadMapping', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sampleData', full_name='com.datavorelabs.common.protos.DataSourceMetaReply.sampleData', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='columnSamples', full_name='com.datavorelabs.common.protos.DataSourceMetaReply.columnSamples', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2802,
  serialized_end=3144,
)


_LINEDEFINITION = _descriptor.Descriptor(
  name='LineDefinition',
  full_name='com.datavorelabs.common.protos.LineDefinition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='keyPredicateIds', full_name='com.datavorelabs.common.protos.LineDefinition.keyPredicateIds', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keyPath', full_name='com.datavorelabs.common.protos.LineDefinition.keyPath', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timePredicateId', full_name='com.datavorelabs.common.protos.LineDefinition.timePredicateId', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='valuePredicateId', full_name='com.datavorelabs.common.protos.LineDefinition.valuePredicateId', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='frequency', full_name='com.datavorelabs.common.protos.LineDefinition.frequency', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dataSourceId', full_name='com.datavorelabs.common.protos.LineDefinition.dataSourceId', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3147,
  serialized_end=3375,
)


_QUERYCOLUMN = _descriptor.Descriptor(
  name='QueryColumn',
  full_name='com.datavorelabs.common.protos.QueryColumn',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='com.datavorelabs.common.protos.QueryColumn.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='com.datavorelabs.common.protos.QueryColumn.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stringFilter', full_name='com.datavorelabs.common.protos.QueryColumn.stringFilter', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='numberFilter', full_name='com.datavorelabs.common.protos.QueryColumn.numberFilter', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timeFilter', full_name='com.datavorelabs.common.protos.QueryColumn.timeFilter', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3378,
  serialized_end=3669,
)


_LINEQUERY = _descriptor.Descriptor(
  name='LineQuery',
  full_name='com.datavorelabs.common.protos.LineQuery',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='columns', full_name='com.datavorelabs.common.protos.LineQuery.columns', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3671,
  serialized_end=3744,
)


_DATASOURCEQUERYREQUEST = _descriptor.Descriptor(
  name='DataSourceQueryRequest',
  full_name='com.datavorelabs.common.protos.DataSourceQueryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='lineQueries', full_name='com.datavorelabs.common.protos.DataSourceQueryRequest.lineQueries', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3746,
  serialized_end=3834,
)

_OPTIONALSTRING.fields_by_name['value'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_OPTIONALNUMBER.fields_by_name['value'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_OPTIONALTIME.fields_by_name['value'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_DATARECORD.fields_by_name['strings'].message_type = _OPTIONALSTRING
_DATARECORD.fields_by_name['numbers'].message_type = _OPTIONALNUMBER
_DATARECORD.fields_by_name['times'].message_type = _OPTIONALTIME
_DATARECORDSREPLY.fields_by_name['records'].message_type = _DATARECORD
_LISTDATASOURCESREPLY.fields_by_name['dataSources'].message_type = _DATASOURCERESULT
_STRINGCOLUMNCONFIG.fields_by_name['modifier'].enum_type = _PREDICATEMODIFIER
_STRINGCOLUMNCONFIG.fields_by_name['ontology'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_STATICSTRINGCOLUMNCONFIG.fields_by_name['value'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_STATICSTRINGCOLUMNCONFIG.fields_by_name['modifier'].enum_type = _PREDICATEMODIFIER
_STATICSTRINGCOLUMNCONFIG.fields_by_name['ontology'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_STATICNUMBERCOLUMNCONFIG.fields_by_name['value'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_STATICTIMECOLUMNCONFIG.fields_by_name['value'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_COLUMNCONFIG.fields_by_name['stringColumnConfig'].message_type = _STRINGCOLUMNCONFIG
_COLUMNCONFIG.fields_by_name['numberColumnConfig'].message_type = _NUMBERCOLUMNCONFIG
_COLUMNCONFIG.fields_by_name['timeColumnConfig'].message_type = _TIMECOLUMNCONFIG
_COLUMNCONFIG.fields_by_name['staticStringColumnConfig'].message_type = _STATICSTRINGCOLUMNCONFIG
_COLUMNCONFIG.fields_by_name['staticNumberColumnConfig'].message_type = _STATICNUMBERCOLUMNCONFIG
_COLUMNCONFIG.fields_by_name['staticTimeColumnConfig'].message_type = _STATICTIMECOLUMNCONFIG
_COLUMNCONFIG.oneofs_by_name['columnConfig'].fields.append(
  _COLUMNCONFIG.fields_by_name['stringColumnConfig'])
_COLUMNCONFIG.fields_by_name['stringColumnConfig'].containing_oneof = _COLUMNCONFIG.oneofs_by_name['columnConfig']
_COLUMNCONFIG.oneofs_by_name['columnConfig'].fields.append(
  _COLUMNCONFIG.fields_by_name['numberColumnConfig'])
_COLUMNCONFIG.fields_by_name['numberColumnConfig'].containing_oneof = _COLUMNCONFIG.oneofs_by_name['columnConfig']
_COLUMNCONFIG.oneofs_by_name['columnConfig'].fields.append(
  _COLUMNCONFIG.fields_by_name['timeColumnConfig'])
_COLUMNCONFIG.fields_by_name['timeColumnConfig'].containing_oneof = _COLUMNCONFIG.oneofs_by_name['columnConfig']
_COLUMNCONFIG.oneofs_by_name['columnConfig'].fields.append(
  _COLUMNCONFIG.fields_by_name['staticStringColumnConfig'])
_COLUMNCONFIG.fields_by_name['staticStringColumnConfig'].containing_oneof = _COLUMNCONFIG.oneofs_by_name['columnConfig']
_COLUMNCONFIG.oneofs_by_name['columnConfig'].fields.append(
  _COLUMNCONFIG.fields_by_name['staticNumberColumnConfig'])
_COLUMNCONFIG.fields_by_name['staticNumberColumnConfig'].containing_oneof = _COLUMNCONFIG.oneofs_by_name['columnConfig']
_COLUMNCONFIG.oneofs_by_name['columnConfig'].fields.append(
  _COLUMNCONFIG.fields_by_name['staticTimeColumnConfig'])
_COLUMNCONFIG.fields_by_name['staticTimeColumnConfig'].containing_oneof = _COLUMNCONFIG.oneofs_by_name['columnConfig']
_DATALOADMAPPING.fields_by_name['frequency'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_DATALOADMAPPING.fields_by_name['timeTuples'].message_type = _TIMETUPLECONFIG
_ROWSAMPLE.fields_by_name['values'].message_type = _OPTIONALSTRING
_DATASOURCEMETAREPLY.fields_by_name['columnConfigs'].message_type = _COLUMNCONFIG
_DATASOURCEMETAREPLY.fields_by_name['dataLoadMapping'].message_type = _DATALOADMAPPING
_DATASOURCEMETAREPLY.fields_by_name['sampleData'].message_type = _ROWSAMPLE
_DATASOURCEMETAREPLY.fields_by_name['columnSamples'].message_type = _COLUMNSAMPLE
_LINEDEFINITION.fields_by_name['keyPath'].message_type = _OPTIONALSTRING
_LINEDEFINITION.fields_by_name['frequency'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_QUERYCOLUMN.fields_by_name['type'].enum_type = _COLUMNTYPE
_QUERYCOLUMN.fields_by_name['stringFilter'].message_type = _OPTIONALSTRING
_QUERYCOLUMN.fields_by_name['numberFilter'].message_type = _OPTIONALNUMBER
_QUERYCOLUMN.fields_by_name['timeFilter'].message_type = _OPTIONALTIME
_LINEQUERY.fields_by_name['columns'].message_type = _QUERYCOLUMN
_DATASOURCEQUERYREQUEST.fields_by_name['lineQueries'].message_type = _LINEQUERY
DESCRIPTOR.message_types_by_name['OptionalString'] = _OPTIONALSTRING
DESCRIPTOR.message_types_by_name['OptionalNumber'] = _OPTIONALNUMBER
DESCRIPTOR.message_types_by_name['OptionalTime'] = _OPTIONALTIME
DESCRIPTOR.message_types_by_name['DataRecord'] = _DATARECORD
DESCRIPTOR.message_types_by_name['DataRecordsReply'] = _DATARECORDSREPLY
DESCRIPTOR.message_types_by_name['ListDataSourcesRequest'] = _LISTDATASOURCESREQUEST
DESCRIPTOR.message_types_by_name['DataSourceResult'] = _DATASOURCERESULT
DESCRIPTOR.message_types_by_name['ListDataSourcesReply'] = _LISTDATASOURCESREPLY
DESCRIPTOR.message_types_by_name['DataSourceUniquesRequest'] = _DATASOURCEUNIQUESREQUEST
DESCRIPTOR.message_types_by_name['DataSourceMetaRequest'] = _DATASOURCEMETAREQUEST
DESCRIPTOR.message_types_by_name['StringColumnConfig'] = _STRINGCOLUMNCONFIG
DESCRIPTOR.message_types_by_name['NumberColumnConfig'] = _NUMBERCOLUMNCONFIG
DESCRIPTOR.message_types_by_name['TimeColumnConfig'] = _TIMECOLUMNCONFIG
DESCRIPTOR.message_types_by_name['StaticStringColumnConfig'] = _STATICSTRINGCOLUMNCONFIG
DESCRIPTOR.message_types_by_name['StaticNumberColumnConfig'] = _STATICNUMBERCOLUMNCONFIG
DESCRIPTOR.message_types_by_name['StaticTimeColumnConfig'] = _STATICTIMECOLUMNCONFIG
DESCRIPTOR.message_types_by_name['ColumnConfig'] = _COLUMNCONFIG
DESCRIPTOR.message_types_by_name['TimeTupleConfig'] = _TIMETUPLECONFIG
DESCRIPTOR.message_types_by_name['DataLoadMapping'] = _DATALOADMAPPING
DESCRIPTOR.message_types_by_name['ColumnSample'] = _COLUMNSAMPLE
DESCRIPTOR.message_types_by_name['RowSample'] = _ROWSAMPLE
DESCRIPTOR.message_types_by_name['DataSourceMetaReply'] = _DATASOURCEMETAREPLY
DESCRIPTOR.message_types_by_name['LineDefinition'] = _LINEDEFINITION
DESCRIPTOR.message_types_by_name['QueryColumn'] = _QUERYCOLUMN
DESCRIPTOR.message_types_by_name['LineQuery'] = _LINEQUERY
DESCRIPTOR.message_types_by_name['DataSourceQueryRequest'] = _DATASOURCEQUERYREQUEST
DESCRIPTOR.enum_types_by_name['PredicateModifier'] = _PREDICATEMODIFIER
DESCRIPTOR.enum_types_by_name['ColumnType'] = _COLUMNTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

OptionalString = _reflection.GeneratedProtocolMessageType('OptionalString', (_message.Message,), {
  'DESCRIPTOR' : _OPTIONALSTRING,
  '__module__' : 'dv_pyclient.grpc.dataSources_pb2'
  # @@protoc_insertion_point(class_scope:com.datavorelabs.common.protos.OptionalString)
  })
_sym_db.RegisterMessage(OptionalString)

OptionalNumber = _reflection.GeneratedProtocolMessageType('OptionalNumber', (_message.Message,), {
  'DESCRIPTOR' : _OPTIONALNUMBER,
  '__module__' : 'dv_pyclient.grpc.dataSources_pb2'
  # @@protoc_insertion_point(class_scope:com.datavorelabs.common.protos.OptionalNumber)
  })
_sym_db.RegisterMessage(OptionalNumber)

OptionalTime = _reflection.GeneratedProtocolMessageType('OptionalTime', (_message.Message,), {
  'DESCRIPTOR' : _OPTIONALTIME,
  '__module__' : 'dv_pyclient.grpc.dataSources_pb2'
  # @@protoc_insertion_point(class_scope:com.datavorelabs.common.protos.OptionalTime)
  })
_sym_db.RegisterMessage(OptionalTime)

DataRecord = _reflection.GeneratedProtocolMessageType('DataRecord', (_message.Message,), {
  'DESCRIPTOR' : _DATARECORD,
  '__module__' : 'dv_pyclient.grpc.dataSources_pb2'
  # @@protoc_insertion_point(class_scope:com.datavorelabs.common.protos.DataRecord)
  })
_sym_db.RegisterMessage(DataRecord)

DataRecordsReply = _reflection.GeneratedProtocolMessageType('DataRecordsReply', (_message.Message,), {
  'DESCRIPTOR' : _DATARECORDSREPLY,
  '__module__' : 'dv_pyclient.grpc.dataSources_pb2'
  # @@protoc_insertion_point(class_scope:com.datavorelabs.common.protos.DataRecordsReply)
  })
_sym_db.RegisterMessage(DataRecordsReply)

ListDataSourcesRequest = _reflection.GeneratedProtocolMessageType('ListDataSourcesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATASOURCESREQUEST,
  '__module__' : 'dv_pyclient.grpc.dataSources_pb2'
  # @@protoc_insertion_point(class_scope:com.datavorelabs.common.protos.ListDataSourcesRequest)
  })
_sym_db.RegisterMessage(ListDataSourcesRequest)

DataSourceResult = _reflection.GeneratedProtocolMessageType('DataSourceResult', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCERESULT,
  '__module__' : 'dv_pyclient.grpc.dataSources_pb2'
  # @@protoc_insertion_point(class_scope:com.datavorelabs.common.protos.DataSourceResult)
  })
_sym_db.RegisterMessage(DataSourceResult)

ListDataSourcesReply = _reflection.GeneratedProtocolMessageType('ListDataSourcesReply', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATASOURCESREPLY,
  '__module__' : 'dv_pyclient.grpc.dataSources_pb2'
  # @@protoc_insertion_point(class_scope:com.datavorelabs.common.protos.ListDataSourcesReply)
  })
_sym_db.RegisterMessage(ListDataSourcesReply)

DataSourceUniquesRequest = _reflection.GeneratedProtocolMessageType('DataSourceUniquesRequest', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCEUNIQUESREQUEST,
  '__module__' : 'dv_pyclient.grpc.dataSources_pb2'
  # @@protoc_insertion_point(class_scope:com.datavorelabs.common.protos.DataSourceUniquesRequest)
  })
_sym_db.RegisterMessage(DataSourceUniquesRequest)

DataSourceMetaRequest = _reflection.GeneratedProtocolMessageType('DataSourceMetaRequest', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCEMETAREQUEST,
  '__module__' : 'dv_pyclient.grpc.dataSources_pb2'
  # @@protoc_insertion_point(class_scope:com.datavorelabs.common.protos.DataSourceMetaRequest)
  })
_sym_db.RegisterMessage(DataSourceMetaRequest)

StringColumnConfig = _reflection.GeneratedProtocolMessageType('StringColumnConfig', (_message.Message,), {
  'DESCRIPTOR' : _STRINGCOLUMNCONFIG,
  '__module__' : 'dv_pyclient.grpc.dataSources_pb2'
  # @@protoc_insertion_point(class_scope:com.datavorelabs.common.protos.StringColumnConfig)
  })
_sym_db.RegisterMessage(StringColumnConfig)

NumberColumnConfig = _reflection.GeneratedProtocolMessageType('NumberColumnConfig', (_message.Message,), {
  'DESCRIPTOR' : _NUMBERCOLUMNCONFIG,
  '__module__' : 'dv_pyclient.grpc.dataSources_pb2'
  # @@protoc_insertion_point(class_scope:com.datavorelabs.common.protos.NumberColumnConfig)
  })
_sym_db.RegisterMessage(NumberColumnConfig)

TimeColumnConfig = _reflection.GeneratedProtocolMessageType('TimeColumnConfig', (_message.Message,), {
  'DESCRIPTOR' : _TIMECOLUMNCONFIG,
  '__module__' : 'dv_pyclient.grpc.dataSources_pb2'
  # @@protoc_insertion_point(class_scope:com.datavorelabs.common.protos.TimeColumnConfig)
  })
_sym_db.RegisterMessage(TimeColumnConfig)

StaticStringColumnConfig = _reflection.GeneratedProtocolMessageType('StaticStringColumnConfig', (_message.Message,), {
  'DESCRIPTOR' : _STATICSTRINGCOLUMNCONFIG,
  '__module__' : 'dv_pyclient.grpc.dataSources_pb2'
  # @@protoc_insertion_point(class_scope:com.datavorelabs.common.protos.StaticStringColumnConfig)
  })
_sym_db.RegisterMessage(StaticStringColumnConfig)

StaticNumberColumnConfig = _reflection.GeneratedProtocolMessageType('StaticNumberColumnConfig', (_message.Message,), {
  'DESCRIPTOR' : _STATICNUMBERCOLUMNCONFIG,
  '__module__' : 'dv_pyclient.grpc.dataSources_pb2'
  # @@protoc_insertion_point(class_scope:com.datavorelabs.common.protos.StaticNumberColumnConfig)
  })
_sym_db.RegisterMessage(StaticNumberColumnConfig)

StaticTimeColumnConfig = _reflection.GeneratedProtocolMessageType('StaticTimeColumnConfig', (_message.Message,), {
  'DESCRIPTOR' : _STATICTIMECOLUMNCONFIG,
  '__module__' : 'dv_pyclient.grpc.dataSources_pb2'
  # @@protoc_insertion_point(class_scope:com.datavorelabs.common.protos.StaticTimeColumnConfig)
  })
_sym_db.RegisterMessage(StaticTimeColumnConfig)

ColumnConfig = _reflection.GeneratedProtocolMessageType('ColumnConfig', (_message.Message,), {
  'DESCRIPTOR' : _COLUMNCONFIG,
  '__module__' : 'dv_pyclient.grpc.dataSources_pb2'
  # @@protoc_insertion_point(class_scope:com.datavorelabs.common.protos.ColumnConfig)
  })
_sym_db.RegisterMessage(ColumnConfig)

TimeTupleConfig = _reflection.GeneratedProtocolMessageType('TimeTupleConfig', (_message.Message,), {
  'DESCRIPTOR' : _TIMETUPLECONFIG,
  '__module__' : 'dv_pyclient.grpc.dataSources_pb2'
  # @@protoc_insertion_point(class_scope:com.datavorelabs.common.protos.TimeTupleConfig)
  })
_sym_db.RegisterMessage(TimeTupleConfig)

DataLoadMapping = _reflection.GeneratedProtocolMessageType('DataLoadMapping', (_message.Message,), {
  'DESCRIPTOR' : _DATALOADMAPPING,
  '__module__' : 'dv_pyclient.grpc.dataSources_pb2'
  # @@protoc_insertion_point(class_scope:com.datavorelabs.common.protos.DataLoadMapping)
  })
_sym_db.RegisterMessage(DataLoadMapping)

ColumnSample = _reflection.GeneratedProtocolMessageType('ColumnSample', (_message.Message,), {
  'DESCRIPTOR' : _COLUMNSAMPLE,
  '__module__' : 'dv_pyclient.grpc.dataSources_pb2'
  # @@protoc_insertion_point(class_scope:com.datavorelabs.common.protos.ColumnSample)
  })
_sym_db.RegisterMessage(ColumnSample)

RowSample = _reflection.GeneratedProtocolMessageType('RowSample', (_message.Message,), {
  'DESCRIPTOR' : _ROWSAMPLE,
  '__module__' : 'dv_pyclient.grpc.dataSources_pb2'
  # @@protoc_insertion_point(class_scope:com.datavorelabs.common.protos.RowSample)
  })
_sym_db.RegisterMessage(RowSample)

DataSourceMetaReply = _reflection.GeneratedProtocolMessageType('DataSourceMetaReply', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCEMETAREPLY,
  '__module__' : 'dv_pyclient.grpc.dataSources_pb2'
  # @@protoc_insertion_point(class_scope:com.datavorelabs.common.protos.DataSourceMetaReply)
  })
_sym_db.RegisterMessage(DataSourceMetaReply)

LineDefinition = _reflection.GeneratedProtocolMessageType('LineDefinition', (_message.Message,), {
  'DESCRIPTOR' : _LINEDEFINITION,
  '__module__' : 'dv_pyclient.grpc.dataSources_pb2'
  # @@protoc_insertion_point(class_scope:com.datavorelabs.common.protos.LineDefinition)
  })
_sym_db.RegisterMessage(LineDefinition)

QueryColumn = _reflection.GeneratedProtocolMessageType('QueryColumn', (_message.Message,), {
  'DESCRIPTOR' : _QUERYCOLUMN,
  '__module__' : 'dv_pyclient.grpc.dataSources_pb2'
  # @@protoc_insertion_point(class_scope:com.datavorelabs.common.protos.QueryColumn)
  })
_sym_db.RegisterMessage(QueryColumn)

LineQuery = _reflection.GeneratedProtocolMessageType('LineQuery', (_message.Message,), {
  'DESCRIPTOR' : _LINEQUERY,
  '__module__' : 'dv_pyclient.grpc.dataSources_pb2'
  # @@protoc_insertion_point(class_scope:com.datavorelabs.common.protos.LineQuery)
  })
_sym_db.RegisterMessage(LineQuery)

DataSourceQueryRequest = _reflection.GeneratedProtocolMessageType('DataSourceQueryRequest', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCEQUERYREQUEST,
  '__module__' : 'dv_pyclient.grpc.dataSources_pb2'
  # @@protoc_insertion_point(class_scope:com.datavorelabs.common.protos.DataSourceQueryRequest)
  })
_sym_db.RegisterMessage(DataSourceQueryRequest)


_OPTIONALSTRING._options = None
_OPTIONALNUMBER._options = None
_OPTIONALTIME._options = None
_DATARECORD.fields_by_name['strings']._options = None
_DATARECORD.fields_by_name['numbers']._options = None
_DATARECORD.fields_by_name['times']._options = None

_REMOTEDATASOURCE = _descriptor.ServiceDescriptor(
  name='RemoteDataSource',
  full_name='com.datavorelabs.common.protos.RemoteDataSource',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=3953,
  serialized_end=4501,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListDataSources',
    full_name='com.datavorelabs.common.protos.RemoteDataSource.ListDataSources',
    index=0,
    containing_service=None,
    input_type=_LISTDATASOURCESREQUEST,
    output_type=_LISTDATASOURCESREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='dataSourceUniques',
    full_name='com.datavorelabs.common.protos.RemoteDataSource.dataSourceUniques',
    index=1,
    containing_service=None,
    input_type=_DATASOURCEUNIQUESREQUEST,
    output_type=_DATARECORDSREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='sampleDataSourceMeta',
    full_name='com.datavorelabs.common.protos.RemoteDataSource.sampleDataSourceMeta',
    index=2,
    containing_service=None,
    input_type=_DATASOURCEMETAREQUEST,
    output_type=_DATASOURCEMETAREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='dataSourceQuery',
    full_name='com.datavorelabs.common.protos.RemoteDataSource.dataSourceQuery',
    index=3,
    containing_service=None,
    input_type=_DATASOURCEQUERYREQUEST,
    output_type=_DATARECORDSREPLY,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_REMOTEDATASOURCE)

DESCRIPTOR.services_by_name['RemoteDataSource'] = _REMOTEDATASOURCE

# @@protoc_insertion_point(module_scope)
